API Documentation
=================

.. _calib_api:

run_calibration API Documentation
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

.. autoclass:: xpdacq.calib2.RunCalibration

.. _xrun_api:

CustomizedRunEngine API Documentation
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

.. autoclass:: xpdacq.xpdacq.CustomizedRunEngine

   .. automethod:: xpdacq.xpdacq.CustomizedRunEngine.__call__

.. _ScanPlan_api:

Predefined Plans API Documentation
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

.. autofunction:: xpdacq.beamtime.ct
.. autofunction:: xpdacq.beamtime.Tramp
.. autofunction:: xpdacq.beamtime.Tlist
.. autofunction:: xpdacq.beamtime.tseries

Beamtime API Documentation
^^^^^^^^^^^^^^^^^^^^^^^^^^

.. autoclass:: xpdacq.beamtime.Beamtime
.. autoclass:: xpdacq.beamtime.Sample
.. autofunction:: xpdacq.utils.import_sample_info

IPython Setup Documentation
^^^^^^^^^^^^^^^^^^^^^^^^^^^

.. autoclass:: xpdacq.ipysetup.UserInterface

